==> opennebula_3.2.1.orig.tar.gz: opennebula-3.2.1/src/cloud/occi/lib/ui/public/locale/es_ES/es_ES.js <==
//Translated by Hector Sanjuan
lang="es_ES"
datatable_lang="es_datatable.txt"
locale={
    "Additionally, OpenNebula Self-Service allows easy customization of the interface (e.g. this text) and brings multi-language support.":"Además, OpenNebula Self-Service permite una fácil personalización de la interfaz (por ejemplo, de este mismo texto) y viene con soporte para múltiples lenguajes.",
    "Additionally, you can run several operations on defined storages, such as defining their persistance. Persistent images can only be used by 1 virtual machine, and the changes made by it have effect on the base image. Non-persistent images are cloned before being used in a Virtual Machine, therefore changes are lost unless a snapshot is taken prior to Virtual Machine shutdown.":"Además, puede ejecutar varias operaciones en los almacenamientos presentes, como definir su persistencia. Las imágenes persistentes sólo pueden ser usadas por 1 máquina virtual, y los cambios realizados por ella tiene efecto en la imágen base. Las imágenes no persistentes son clonadas antes de ser utilizadas en una máquina virtual, por tanto los cambios se pierden a menos que se tome una instantánea antes de apagar la máquina virtual.",
    "Additionally, you can take a 'snapshot' of the storage attached to these resources. They will be saved as new resources, visible from the Storage view and re-usable.":"Además, puede tomar una 'instantánea' de los almacenamientos asociado a estos recursos. Ésta será salvaguardada como un nuevo recurso, visible y reutilizable desde la vista de almacenamientos.",
    "Address":"Dirección",
    "Add storage":"Añadir almacenamiento",
    "All":"Todos",
    "are mandatory":"son obligatorios",
    "Cancel":"Cancelar",
    "Cannot contact server: is it running and reachable?":"No se puede contactar con el servidor: ¿está funcionando y es alcanzable?",
    "Canvas not supported.":"Canvas no soportado",
    "CD-ROM":"CD-ROM",
    "Changing language":"Cambiando el lenguaje",
    "Close":"Cerrar",
    "Community":"Comunidad",
    "Compute":"Máquinas Virtuales",
    "Compute resource":"máquina virtual",
    "Compute resources are Virtual Machines attached to storage and network resources. OpenNebula Self-Service allows you to easily create, remove and manage them, including the possibility of pausing a Virtual Machine or taking a snapshot of one of their disks.":"Las máquinas virtuales están asociadas a recursos de almacenamiento y de red. OpenNebula Self-Service le permite crearlos, borrarlos y administrarlos fácilmente, incluyendo la posibilidad de pausar una máquina virtual o de tomar una instantánea de alguno de sus discos.",
    "Compute resources can be attached to these networks at creation time. Virtual machines will be provided with an IP and the correct parameters to ensure connectivity.":"Las máquinas virtuales pueden asociarse a estas redes en el momento de su creación. Las máquinas virtuales serán provistas de una IP y de los parámetros correctos para asegurar conectividad.",
    "Configuration":"Configuración",
    "Confirmation of action":"Confirmar operación",
    "CPU":"CPU",
    "Create":"Crear",
    "Create network":"Crear red",
    "Create new compute resource":"Crear nueva máquina virtual",
    "Create new network resource":"Crear nueva red",
    "Create new storage resource":"Crear nuevo almacenamiento",
    "Create Virtual Machine":"Crear máquina virtual",
    "Create # VMs":"Crear # MVs",
    "Current resources":"Recursos actuales",
    "Dashboard":"Portada",
    "Datablock":"Datablock",
    "Delete":"Borrar",
    "Description":"Descripción",
    "disk id":"id del disco",
    "Disks":"Discos",
    "Disks information":"Información de discos",
    "Documentation":"Documentación",
    "Do you want to proceed?":"¿Desea continuar?",
    "English":"Inglés",
    "Error":"Error",
    "Fields marked with":"Campos marcados con",
    "Filesystem type":"Sistema de ficheros",
    "FS type":"tipo de FS",
    "Have a cloudy experience!":"¡Nos vemos en las nubes!",
    "Human readable description of the image.":"Descripción de la imagen.",
    "ID":"ID",
    "Image":"Imagen",
    "Image information":"Información de la imagen",
    "Image name":"Nombre de la imagen",
    "images":"imágenes",
    "Images":"Imágenes",
    "Info":"Información",
    "information":"Información",
    "Instance type":"Tipo de instancia",
    "In this view you can easily manage OpenNebula Network resources. You can add or remove virtual networks.":"En esta vista puede gestionar fácilmente los recursos de red de OpenNebula. Puede añadir o borrar redes virtuales.",
    "IP":"IP",
    "Language":"Lenguaje",
    "Loading":"Cargando",
    "Loading new language... please wait":"Cargando nuevo lenguaje... espere, por favor",
    "MAC":"MAC",
    "Make non persistent":"Hacer no persistente",
    "Make persistent":"Hacer persistente",
    "Memory":"Memoria",
    "Monitoring information":"Información de monitorización",
    "Name":"Nombre",
    "Name that the Image will get.":"Nombre para la imagen.",
    "Network":"Red",
    "Network Address":"Dirección de red",
    "Network information":"Información de red",
    "Network is unreachable: is OpenNebula running?":"No se puede alcanzar la red: ¿está OpenNebula funcionando?",
    "Network reception":"Recepción de red",
    "networks":"redes",
    "Networks":"Redes",
    "Networks information":"Información de redes",
    "Network Size":"Tamaño de red",
    "Network transmission":"Transmisión de red",
    "+ New":"+ Nuevo",
    "No disk id or image name specified":"No se ha especificado ID de disco o nombre de la imagen",
    "No disks defined":"No hay discos definidos",
    "No networks defined":"No hay redes definidas",
    "OK":"OK",
    "OpenNebula Self-Service is a simplified user interface to manage OpenNebula compute, storage and network resources. It is focused on easiness and usability and features a limited set of operations directed towards end-users.":"OpenNebula Self-Service es una interfaz de usuario simplificada para administrar máquinas virtuales, almacenamiento y red de OpenNebula. Está basada en la facilidad de uso y cuenta con un número limitado de operaciones dirigidas a los usuarios finales.",
    "Open VNC Session":"Abrir sesión VNC",
    "OS":"OS",
    "Persistence of the image":"Persistencia de la imagen",
    "Persistent":"Persistente",
    "Please, choose and modify the template you want to update":"Por favor, escoja y modifique la plantilla que desea actualizar",
    "Please provide a network address":"Por favor, proporcione una dirección de red",
    "Please select":"Por favor escoja",
    "Previous action":"Acción anterior",
    "Public":"Público",
    "Public scope of the image":"Imagen pública",
    "Publish":"Publicar",
    "Refresh list":"Refrescar lista",
    "Resume":"Reanudar",
    "Retrieving":"Cargando",
    "Saveas for VM with ID":"Instantánea a MV con ID",
    "See more":"Ver más",
    "Select a template":"Seleccione una plantilla",
    "Select disk":"Seleccione un disco",
    "Select image to upload":"Seleccione una imagen para subir",
    "Self-Service UI Configuration":"Configuración de la interfaz Self-Service",
    "Shutdown":"Apagar",
    "Sign out":"Desconectar",
    "Size":"Tamaño",
    "Size (Mb)":"Tamaño (Mb)",
    "Size of the datablock in MB.":"Tamaño del datablcok en MB",
    "Skipping VM ":"Saltando MV",
    "Spanish":"Español",
    "State":"Estado",
    "Stop":"Detener",
    "Storage":"Almacenamiento",
    "Storage pool is formed by several images. These images can contain from full operating systems to be used as base for compute resources, to simple data. OpenNebula Self-Service offers you the possibility to create or upload your own images.":"La lista de almacenamiento está formada por varias imágenes. Estas imágenes pueden contener desde sistemas operativos completos para ser usados como base en máquinas virtuales, hasta simples datos. OpenNebula Self-Service ofrece la posibilidad de crear o subir sus propias imágenes.",
    "String":"String",
    "style":"estilo",
    "Submitted":"Hecho",
    "Support":"Soporte",
    "Suspend":"Suspender",
    "Take snapshot":"Tomar instantánea",
    "Target":"Target",
    "There are currently":"Actualmente hay",
    "The Storage view offers you an overview of your current images. Storage elements are attached to compute resources at creation time. They can also be extracted from running virtual machines by taking an snapshot.":"La vista de almacenamiento le ofrece la visión general de sus imágenes. Los elementos de almacenamiento se asocian a máquinas virtuales en el momento de la creación. También pueden ser extraídos de una máquina virtual en ejecución tomando una instantánea",
    "This is a list of your current compute resources. Virtual Machines use previously defined images and networks. You can easily create a new compute element by cliking 'new' and filling-in an easy wizard.":"Esta es una lista de sus máquinas virtuales actuales. Las máquinas virtuales utilizan imagenes y redes definidas previamente. Puede crear fácilmente una nueva máquina virtual haciendo click en 'New' y rellenado un sencillo formulario.",
    "This will cancel selected VMs":"Esto cancelará las MVs seleccionadas",
    "This will delete the selected VMs from the database":"Esto borrará las MVs seleccionadas de la base de datos",
    "This will resume the selected VMs in stopped or suspended states":"Esto reanudará las MVs seleccionadas paradas o suspendidas",
    "This will shutdown the selected VMs":"Esto apagará las MVs seleccionadas",
    "This will suspend the selected VMs":"Esto suspenderá las MVs seleccionadas",
    "Type":"Tipo",
    "Type of file system to be built. This can be any value understood by mkfs unix command.":"Tipo de sistema de archivos a generar. Es válido cualquier valor entendido por el comando mkfs",
    "Type of the image":"Tipo de la imagen",
    "Unauthorized":"No autorizado",
    "Unpublish":"Despublicar",
    "Update":"Actualizar",
    "Update template":"Actualizar plantilla",
    "Used leases":"Leases usados",
    "Useful links":"Enlances útiles",
    "Virtual Machine information":"Información de máquina virtual",
    "virtual machines":"máquinas virtuales",
    "Virtual Network":"Red virtual",
    "Virtual Network information":"Información de red virtual",
    "Virtual Network name missing!":"¡Falta el nombre de la red!",
    "VM information":"Información de MV",
    "VM Name":"Nombre",
    "VNC connection":"Conexión VNC",
    "VNC Disabled":"VNC Desabilitado",
    "Welcome":"Bienvenid@",
    "Welcome to OpenNebula Self-Service":"Bienvenid@ a OpenNebula Self-Service",
    "You can add new storages by clicking 'new'. Image files will be uploaded to OpenNebula and set ready to be used.":"Puede añadir nuevos almacenamientos haciendo click en 'new'. Los ficheros de imagen pueden ser subidos a OpenNebula y preparados para ser usado.",
    "You can also manage compute resources and perform actions such as stop, resume, shutdown or cancel.":"También puede administrar las máquinas virtuales y realizar acciones como detener, reanudar, apagar o cancelar.",
    "You have to confirm this action.":"Necesita confirmar esta acción",
    "You must select a file to upload":"Debe seleccionar un fichero para subir",
    "You must specify a name":"Debe especificar un nombre",
    "You must specify size and FS type":"Debe especificar un tamaño y un tipo de FS",
    "You need to select something.":"Debe seleccionar algo",
    "Your compute resources connectivity is performed using pre-defined virtual networks. You can create and manage these networks using OpenNebula Self-Service.":"La conectividad de sus máquinas virtuales se realiza usando redes virtuales pre-definidas. Puede crear y administrar estas redes usando OpenNebula Self-Service.",
};

==> opennebula_3.4.1.orig.tar.gz: opennebula-3.4.1/src/cloud/occi/lib/ui/public/locale/es_ES/es_ES.js <==
//Translated by Hector Sanjuan
lang="es_ES"
datatable_lang="es_datatable.txt"
locale={
    "Additionally, OpenNebula Self-Service allows easy customization of the interface (e.g. this text) and brings multi-language support.":"Además, OpenNebula Self-Service permite una fácil personalización de la interfaz (por ejemplo, de este mismo texto) y viene con soporte para múltiples lenguajes.",
    "Additionally, you can run several operations on defined storages, such as defining their persistance. Persistent images can only be used by 1 virtual machine, and the changes made by it have effect on the base image. Non-persistent images are cloned before being used in a Virtual Machine, therefore changes are lost unless a snapshot is taken prior to Virtual Machine shutdown.":"Además, puede ejecutar varias operaciones en los almacenamientos presentes, como definir su persistencia. Las imágenes persistentes sólo pueden ser usadas por 1 máquina virtual, y los cambios realizados por ella tiene efecto en la imágen base. Las imágenes no persistentes son clonadas antes de ser utilizadas en una máquina virtual, por tanto los cambios se pierden a menos que se tome una instantánea antes de apagar la máquina virtual.",
    "Additionally, you can take a 'snapshot' of the storage attached to these resources. They will be saved as new resources, visible from the Storage view and re-usable.":"Además, puede tomar una 'instantánea' de los almacenamientos asociado a estos recursos. Ésta será salvaguardada como un nuevo recurso, visible y reutilizable desde la vista de almacenamientos.",
    "Address":"Dirección",
    "Add storage":"Añadir almacenamiento",
    "All":"Todos",
    "are mandatory":"son obligatorios",
    "Cancel":"Cancelar",
    "Cannot contact server: is it running and reachable?":"No se puede contactar con el servidor: ¿está funcionando y es alcanzable?",
    "Canvas not supported.":"Canvas no soportado",
    "CD-ROM":"CD-ROM",
    "Changing language":"Cambiando el lenguaje",
    "Close":"Cerrar",
    "Community":"Comunidad",
    "Compute":"Máquinas Virtuales",
    "Compute resource":"máquina virtual",
    "Compute resources are Virtual Machines attached to storage and network resources. OpenNebula Self-Service allows you to easily create, remove and manage them, including the possibility of pausing a Virtual Machine or taking a snapshot of one of their disks.":"Las máquinas virtuales están asociadas a recursos de almacenamiento y de red. OpenNebula Self-Service le permite crearlos, borrarlos y administrarlos fácilmente, incluyendo la posibilidad de pausar una máquina virtual o de tomar una instantánea de alguno de sus discos.",
    "Compute resources can be attached to these networks at creation time. Virtual machines will be provided with an IP and the correct parameters to ensure connectivity.":"Las máquinas virtuales pueden asociarse a estas redes en el momento de su creación. Las máquinas virtuales serán provistas de una IP y de los parámetros correctos para asegurar conectividad.",
    "Configuration":"Configuración",
    "Confirmation of action":"Confirmar operación",
    "CPU":"CPU",
    "Create":"Crear",
    "Create network":"Crear red",
    "Create new compute resource":"Crear nueva máquina virtual",
    "Create new network resource":"Crear nueva red",
    "Create new storage resource":"Crear nuevo almacenamiento",
    "Create Virtual Machine":"Crear máquina virtual",
    "Create # VMs":"Crear # MVs",
    "Current resources":"Recursos actuales",
    "Dashboard":"Portada",
    "Datablock":"Datablock",
    "Delete":"Borrar",
    "Description":"Descripción",
    "disk id":"id del disco",
    "Disks":"Discos",
    "Disks information":"Información de discos",
    "Documentation":"Documentación",
    "Do you want to proceed?":"¿Desea continuar?",
    "English":"Inglés",
    "Error":"Error",
    "Fields marked with":"Campos marcados con",
    "Filesystem type":"Sistema de ficheros",
    "FS type":"tipo de FS",
    "Have a cloudy experience!":"¡Nos vemos en las nubes!",
    "Human readable description of the image.":"Descripción de la imagen.",
    "ID":"ID",
    "Image":"Imagen",
    "Image information":"Información de la imagen",
    "Image name":"Nombre de la imagen",
    "images":"imágenes",
    "Images":"Imágenes",
    "Info":"Información",
    "information":"Información",
    "Instance type":"Tipo de instancia",
    "In this view you can easily manage OpenNebula Network resources. You can add or remove virtual networks.":"En esta vista puede gestionar fácilmente los recursos de red de OpenNebula. Puede añadir o borrar redes virtuales.",
    "IP":"IP",
    "Language":"Lenguaje",
    "Launch VNC session":"Lanzar sesión VNC",
    "Loading":"Cargando",
    "Loading new language... please wait":"Cargando nuevo lenguaje... espere, por favor",
    "MAC":"MAC",
    "Make non persistent":"Hacer no persistente",
    "Make persistent":"Hacer persistente",
    "Memory":"Memoria",
    "Monitoring information":"Información de monitorización",
    "Name":"Nombre",
    "Name that the Image will get.":"Nombre para la imagen.",
    "Network":"Red",
    "Network Address":"Dirección de red",
    "Network information":"Información de red",
    "Network is unreachable: is OpenNebula running?":"No se puede alcanzar la red: ¿está OpenNebula funcionando?",
    "Network reception":"Recepción de red",
    "networks":"redes",
    "Networks":"Redes",
    "Networks information":"Información de redes",
    "Network Size":"Tamaño de red",
    "Network transmission":"Transmisión de red",
    "+ New":"+ Nuevo",
    "No disk id or image name specified":"No se ha especificado ID de disco o nombre de la imagen",
    "No disks defined":"No hay discos definidos",
    "No networks defined":"No hay redes definidas",
    "OK":"OK",
    "OpenNebula Self-Service is a simplified user interface to manage OpenNebula compute, storage and network resources. It is focused on easiness and usability and features a limited set of operations directed towards end-users.":"OpenNebula Self-Service es una interfaz de usuario simplificada para administrar máquinas virtuales, almacenamiento y red de OpenNebula. Está basada en la facilidad de uso y cuenta con un número limitado de operaciones dirigidas a los usuarios finales.",
    "Open VNC Session":"Abrir sesión VNC",
    "OS":"OS",
    "Persistence of the image":"Persistencia de la imagen",
    "Persistent":"Persistente",
    "Please, choose and modify the template you want to update":"Por favor, escoja y modifique la plantilla que desea actualizar",
    "Please provide a network address":"Por favor, proporcione una dirección de red",
    "Please select":"Por favor escoja",
    "Previous action":"Acción anterior",
    "Public":"Público",
    "Public scope of the image":"Imagen pública",
    "Publish":"Publicar",
    "Refresh list":"Refrescar lista",
    "Resume":"Reanudar",
    "Retrieving":"Cargando",
    "Saveas for VM with ID":"Instantánea a MV con ID",
    "See more":"Ver más",
    "Select a template":"Seleccione una plantilla",
    "Select disk":"Seleccione un disco",
    "Select image to upload":"Seleccione una imagen para subir",
    "Self-Service UI Configuration":"Configuración de la interfaz Self-Service",
    "Shutdown":"Apagar",
    "Sign out":"Desconectar",
    "Size":"Tamaño",
    "Size (Mb)":"Tamaño (Mb)",
    "Size of the datablock in MB.":"Tamaño del datablcok en MB",
    "Skipping VM ":"Saltando MV",
    "Spanish":"Español",
    "State":"Estado",
    "Stop":"Detener",
    "Storage":"Almacenamiento",
    "Storage pool is formed by several images. These images can contain from full operating systems to be used as base for compute resources, to simple data. OpenNebula Self-Service offers you the possibility to create or upload your own images.":"La lista de almacenamiento está formada por varias imágenes. Estas imágenes pueden contener desde sistemas operativos completos para ser usados como base en máquinas virtuales, hasta simples datos. OpenNebula Self-Service ofrece la posibilidad de crear o subir sus propias imágenes.",
    "String":"String",
    "style":"estilo",
    "Submitted":"Hecho",
    "Support":"Soporte",
    "Suspend":"Suspender",
    "Take snapshot":"Tomar instantánea",
    "Target":"Target",
    "There are currently":"Actualmente hay",
    "The Storage view offers you an overview of your current images. Storage elements are attached to compute resources at creation time. They can also be extracted from running virtual machines by taking an snapshot.":"La vista de almacenamiento le ofrece la visión general de sus imágenes. Los elementos de almacenamiento se asocian a máquinas virtuales en el momento de la creación. También pueden ser extraídos de una máquina virtual en ejecución tomando una instantánea",
    "This is a list of your current compute resources. Virtual Machines use previously defined images and networks. You can easily create a new compute element by cliking 'new' and filling-in an easy wizard.":"Esta es una lista de sus máquinas virtuales actuales. Las máquinas virtuales utilizan imagenes y redes definidas previamente. Puede crear fácilmente una nueva máquina virtual haciendo click en 'New' y rellenado un sencillo formulario.",
    "This will cancel selected VMs":"Esto cancelará las MVs seleccionadas",
    "This will delete the selected VMs from the database":"Esto borrará las MVs seleccionadas de la base de datos",
    "This will resume the selected VMs in stopped or suspended states":"Esto reanudará las MVs seleccionadas paradas o suspendidas",
    "This will shutdown the selected VMs":"Esto apagará las MVs seleccionadas",
    "This will suspend the selected VMs":"Esto suspenderá las MVs seleccionadas",
    "Type":"Tipo",
    "Type of file system to be built. This can be any value understood by mkfs unix command.":"Tipo de sistema de archivos a generar. Es válido cualquier valor entendido por el comando mkfs",
    "Type of the image":"Tipo de la imagen",
    "Unauthorized":"No autorizado",
    "Unpublish":"Despublicar",
    "Update":"Actualizar",
    "Update template":"Actualizar plantilla",
    "Used leases":"Leases usados",
    "Useful links":"Enlances útiles",
    "Virtual Machine information":"Información de máquina virtual",
    "virtual machines":"máquinas virtuales",
    "Virtual Network":"Red virtual",
    "Virtual Network information":"Información de red virtual",
    "Virtual Network name missing!":"¡Falta el nombre de la red!",
    "VM information":"Información de MV",
    "VM Name":"Nombre",
    "VNC connection":"Conexión VNC",
    "VNC Disabled":"VNC Desabilitado",
    "Welcome":"Bienvenid@",
    "Welcome to OpenNebula Self-Service":"Bienvenid@ a OpenNebula Self-Service",
    "You can add new storages by clicking 'new'. Image files will be uploaded to OpenNebula and set ready to be used.":"Puede añadir nuevos almacenamientos haciendo click en 'new'. Los ficheros de imagen pueden ser subidos a OpenNebula y preparados para ser usado.",
    "You can also manage compute resources and perform actions such as stop, resume, shutdown or cancel.":"También puede administrar las máquinas virtuales y realizar acciones como detener, reanudar, apagar o cancelar.",
    "You can use the wildcard %i. When creating several VMs, %i will be replaced with a different number starting from 0 in each of them":"Puede utilizar el comodín %i. Durante la creación de varias máquinas virtuales, %i será reemplazado por un número distinto en cada una de ellas, empezando por 0",
    "You have to confirm this action.":"Necesita confirmar esta acción",
    "You must select a file to upload":"Debe seleccionar un fichero para subir",
    "You must specify a name":"Debe especificar un nombre",
    "You must specify size and FS type":"Debe especificar un tamaño y un tipo de FS",
    "You need to select something.":"Debe seleccionar algo",
    "Your compute resources connectivity is performed using pre-defined virtual networks. You can create and manage these networks using OpenNebula Self-Service.":"La conectividad de sus máquinas virtuales se realiza usando redes virtuales pre-definidas. Puede crear y administrar estas redes usando OpenNebula Self-Service.",
};
